@@ -48,15 +48,15 @@ sub setup()
         'Directive'        => [$ANSI_colors{'magenta'},  $ANSI_colors{'none'}],
         'Label'            => [$ANSI_colors{'magenta'},  $ANSI_colors{'none'}],
         'Quote'            => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
-        'String'           => [$ANSI_colors{'gray'},    $ANSI_colors{'none'}],
-        'Subroutine'       => [$ANSI_colors{'bblue'},    $ANSI_colors{'none'}],
+        'String'           => [$ANSI_colors{'gray'},     $ANSI_colors{'none'}],
+        'Subroutine'       => [$ANSI_colors{'blue'},     $ANSI_colors{'none'}],
         'Variable_Scalar'  => [$ANSI_colors{'bgreen'},   $ANSI_colors{'none'}],
         'Variable_Array'   => [$ANSI_colors{'magenta'},   $ANSI_colors{'none'}],
         'Variable_Hash'    => [$ANSI_colors{'bgreen'},   $ANSI_colors{'none'}],
         'Variable_Typeglob'=> [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
         'Whitespace'       => ['',                       ''                  ],
         'Character'        => [$ANSI_colors{'bred'},     $ANSI_colors{'none'}],
-        'Keyword'          => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
+        'Keyword'          => [$ANSI_colors{'bblue'},    $ANSI_colors{'none'}],
         'Builtin_Function' => [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
         'Builtin_Operator' => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
         'Operator'         => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
